==> zio-aws-sagemaker_2.12-5.19.17.1-sources.jar: zio/aws/sagemaker/model/AlgorithmSpecification.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{
  TrainingContainerArgument,
  TrainingContainerEntrypointString,
  ArnOrName,
  AlgorithmImage
}
import scala.jdk.CollectionConverters._
final case class AlgorithmSpecification(
    trainingImage: Optional[AlgorithmImage] = Optional.Absent,
    algorithmName: Optional[ArnOrName] = Optional.Absent,
    trainingInputMode: zio.aws.sagemaker.model.TrainingInputMode,
    metricDefinitions: Optional[
      Iterable[zio.aws.sagemaker.model.MetricDefinition]
    ] = Optional.Absent,
    enableSageMakerMetricsTimeSeries: Optional[Boolean] = Optional.Absent,
    containerEntrypoint: Optional[Iterable[TrainingContainerEntrypointString]] =
      Optional.Absent,
    containerArguments: Optional[Iterable[TrainingContainerArgument]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification = {
    import AlgorithmSpecification.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification
      .builder()
      .optionallyWith(
        trainingImage.map(value =>
          AlgorithmImage.unwrap(value): java.lang.String
        )
      )(_.trainingImage)
      .optionallyWith(
        algorithmName.map(value => ArnOrName.unwrap(value): java.lang.String)
      )(_.algorithmName)
      .trainingInputMode(trainingInputMode.unwrap)
      .optionallyWith(
        metricDefinitions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.metricDefinitions)
      .optionallyWith(
        enableSageMakerMetricsTimeSeries.map(value => value: java.lang.Boolean)
      )(_.enableSageMakerMetricsTimeSeries)
      .optionallyWith(
        containerEntrypoint.map(value =>
          value.map { item =>
            TrainingContainerEntrypointString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.containerEntrypoint)
      .optionallyWith(
        containerArguments.map(value =>
          value.map { item =>
            TrainingContainerArgument.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.containerArguments)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.AlgorithmSpecification.ReadOnly =
    zio.aws.sagemaker.model.AlgorithmSpecification.wrap(buildAwsValue())
}
object AlgorithmSpecification {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.AlgorithmSpecification =
      zio.aws.sagemaker.model.AlgorithmSpecification(
        trainingImage.map(value => value),
        algorithmName.map(value => value),
        trainingInputMode,
        metricDefinitions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        enableSageMakerMetricsTimeSeries.map(value => value),
        containerEntrypoint.map(value => value),
        containerArguments.map(value => value)
      )
    def trainingImage: Optional[AlgorithmImage]
    def algorithmName: Optional[ArnOrName]
    def trainingInputMode: zio.aws.sagemaker.model.TrainingInputMode
    def metricDefinitions
        : Optional[List[zio.aws.sagemaker.model.MetricDefinition.ReadOnly]]
    def enableSageMakerMetricsTimeSeries: Optional[Boolean]
    def containerEntrypoint: Optional[List[TrainingContainerEntrypointString]]
    def containerArguments: Optional[List[TrainingContainerArgument]]
    def getTrainingImage: ZIO[Any, AwsError, AlgorithmImage] =
      AwsError.unwrapOptionField("trainingImage", trainingImage)
    def getAlgorithmName: ZIO[Any, AwsError, ArnOrName] =
      AwsError.unwrapOptionField("algorithmName", algorithmName)
    def getTrainingInputMode
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.TrainingInputMode] =
      ZIO.succeed(trainingInputMode)
    def getMetricDefinitions: ZIO[Any, AwsError, List[
      zio.aws.sagemaker.model.MetricDefinition.ReadOnly
    ]] = AwsError.unwrapOptionField("metricDefinitions", metricDefinitions)
    def getEnableSageMakerMetricsTimeSeries: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "enableSageMakerMetricsTimeSeries",
        enableSageMakerMetricsTimeSeries
      )
    def getContainerEntrypoint
        : ZIO[Any, AwsError, List[TrainingContainerEntrypointString]] =
      AwsError.unwrapOptionField("containerEntrypoint", containerEntrypoint)
    def getContainerArguments
        : ZIO[Any, AwsError, List[TrainingContainerArgument]] =
      AwsError.unwrapOptionField("containerArguments", containerArguments)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification
  ) extends zio.aws.sagemaker.model.AlgorithmSpecification.ReadOnly {
    override val trainingImage: Optional[AlgorithmImage] = zio.aws.core.internal
      .optionalFromNullable(impl.trainingImage())
      .map(value => zio.aws.sagemaker.model.primitives.AlgorithmImage(value))
    override val algorithmName: Optional[ArnOrName] = zio.aws.core.internal
      .optionalFromNullable(impl.algorithmName())
      .map(value => zio.aws.sagemaker.model.primitives.ArnOrName(value))
    override val trainingInputMode: zio.aws.sagemaker.model.TrainingInputMode =
      zio.aws.sagemaker.model.TrainingInputMode.wrap(impl.trainingInputMode())
    override val metricDefinitions
        : Optional[List[zio.aws.sagemaker.model.MetricDefinition.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metricDefinitions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.MetricDefinition.wrap(item)
          }.toList
        )
    override val enableSageMakerMetricsTimeSeries: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enableSageMakerMetricsTimeSeries())
        .map(value => value: Boolean)
    override val containerEntrypoint
        : Optional[List[TrainingContainerEntrypointString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.containerEntrypoint())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.primitives
              .TrainingContainerEntrypointString(item)
          }.toList
        )
    override val containerArguments: Optional[List[TrainingContainerArgument]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.containerArguments())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.primitives.TrainingContainerArgument(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification
  ): zio.aws.sagemaker.model.AlgorithmSpecification.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_2.12-6.20.74.1-sources.jar: zio/aws/sagemaker/model/AlgorithmSpecification.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{
  TrainingContainerArgument,
  TrainingContainerEntrypointString,
  ArnOrName,
  AlgorithmImage
}
import scala.jdk.CollectionConverters._
final case class AlgorithmSpecification(
    trainingImage: Optional[AlgorithmImage] = Optional.Absent,
    algorithmName: Optional[ArnOrName] = Optional.Absent,
    trainingInputMode: zio.aws.sagemaker.model.TrainingInputMode,
    metricDefinitions: Optional[
      Iterable[zio.aws.sagemaker.model.MetricDefinition]
    ] = Optional.Absent,
    enableSageMakerMetricsTimeSeries: Optional[Boolean] = Optional.Absent,
    containerEntrypoint: Optional[Iterable[TrainingContainerEntrypointString]] =
      Optional.Absent,
    containerArguments: Optional[Iterable[TrainingContainerArgument]] =
      Optional.Absent,
    trainingImageConfig: Optional[zio.aws.sagemaker.model.TrainingImageConfig] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification = {
    import AlgorithmSpecification.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification
      .builder()
      .optionallyWith(
        trainingImage.map(value =>
          AlgorithmImage.unwrap(value): java.lang.String
        )
      )(_.trainingImage)
      .optionallyWith(
        algorithmName.map(value => ArnOrName.unwrap(value): java.lang.String)
      )(_.algorithmName)
      .trainingInputMode(trainingInputMode.unwrap)
      .optionallyWith(
        metricDefinitions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.metricDefinitions)
      .optionallyWith(
        enableSageMakerMetricsTimeSeries.map(value => value: java.lang.Boolean)
      )(_.enableSageMakerMetricsTimeSeries)
      .optionallyWith(
        containerEntrypoint.map(value =>
          value.map { item =>
            TrainingContainerEntrypointString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.containerEntrypoint)
      .optionallyWith(
        containerArguments.map(value =>
          value.map { item =>
            TrainingContainerArgument.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.containerArguments)
      .optionallyWith(trainingImageConfig.map(value => value.buildAwsValue()))(
        _.trainingImageConfig
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.AlgorithmSpecification.ReadOnly =
    zio.aws.sagemaker.model.AlgorithmSpecification.wrap(buildAwsValue())
}
object AlgorithmSpecification {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.AlgorithmSpecification =
      zio.aws.sagemaker.model.AlgorithmSpecification(
        trainingImage.map(value => value),
        algorithmName.map(value => value),
        trainingInputMode,
        metricDefinitions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        enableSageMakerMetricsTimeSeries.map(value => value),
        containerEntrypoint.map(value => value),
        containerArguments.map(value => value),
        trainingImageConfig.map(value => value.asEditable)
      )
    def trainingImage: Optional[AlgorithmImage]
    def algorithmName: Optional[ArnOrName]
    def trainingInputMode: zio.aws.sagemaker.model.TrainingInputMode
    def metricDefinitions
        : Optional[List[zio.aws.sagemaker.model.MetricDefinition.ReadOnly]]
    def enableSageMakerMetricsTimeSeries: Optional[Boolean]
    def containerEntrypoint: Optional[List[TrainingContainerEntrypointString]]
    def containerArguments: Optional[List[TrainingContainerArgument]]
    def trainingImageConfig
        : Optional[zio.aws.sagemaker.model.TrainingImageConfig.ReadOnly]
    def getTrainingImage: ZIO[Any, AwsError, AlgorithmImage] =
      AwsError.unwrapOptionField("trainingImage", trainingImage)
    def getAlgorithmName: ZIO[Any, AwsError, ArnOrName] =
      AwsError.unwrapOptionField("algorithmName", algorithmName)
    def getTrainingInputMode
        : ZIO[Any, Nothing, zio.aws.sagemaker.model.TrainingInputMode] =
      ZIO.succeed(trainingInputMode)
    def getMetricDefinitions: ZIO[Any, AwsError, List[
      zio.aws.sagemaker.model.MetricDefinition.ReadOnly
    ]] = AwsError.unwrapOptionField("metricDefinitions", metricDefinitions)
    def getEnableSageMakerMetricsTimeSeries: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "enableSageMakerMetricsTimeSeries",
        enableSageMakerMetricsTimeSeries
      )
    def getContainerEntrypoint
        : ZIO[Any, AwsError, List[TrainingContainerEntrypointString]] =
      AwsError.unwrapOptionField("containerEntrypoint", containerEntrypoint)
    def getContainerArguments
        : ZIO[Any, AwsError, List[TrainingContainerArgument]] =
      AwsError.unwrapOptionField("containerArguments", containerArguments)
    def getTrainingImageConfig: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.TrainingImageConfig.ReadOnly
    ] = AwsError.unwrapOptionField("trainingImageConfig", trainingImageConfig)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification
  ) extends zio.aws.sagemaker.model.AlgorithmSpecification.ReadOnly {
    override val trainingImage: Optional[AlgorithmImage] = zio.aws.core.internal
      .optionalFromNullable(impl.trainingImage())
      .map(value => zio.aws.sagemaker.model.primitives.AlgorithmImage(value))
    override val algorithmName: Optional[ArnOrName] = zio.aws.core.internal
      .optionalFromNullable(impl.algorithmName())
      .map(value => zio.aws.sagemaker.model.primitives.ArnOrName(value))
    override val trainingInputMode: zio.aws.sagemaker.model.TrainingInputMode =
      zio.aws.sagemaker.model.TrainingInputMode.wrap(impl.trainingInputMode())
    override val metricDefinitions
        : Optional[List[zio.aws.sagemaker.model.MetricDefinition.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.metricDefinitions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.MetricDefinition.wrap(item)
          }.toList
        )
    override val enableSageMakerMetricsTimeSeries: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.enableSageMakerMetricsTimeSeries())
        .map(value => value: Boolean)
    override val containerEntrypoint
        : Optional[List[TrainingContainerEntrypointString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.containerEntrypoint())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.primitives
              .TrainingContainerEntrypointString(item)
          }.toList
        )
    override val containerArguments: Optional[List[TrainingContainerArgument]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.containerArguments())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.primitives.TrainingContainerArgument(item)
          }.toList
        )
    override val trainingImageConfig
        : Optional[zio.aws.sagemaker.model.TrainingImageConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.trainingImageConfig())
        .map(value => zio.aws.sagemaker.model.TrainingImageConfig.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.AlgorithmSpecification
  ): zio.aws.sagemaker.model.AlgorithmSpecification.ReadOnly = new Wrapper(impl)
}
